#
# spec file for package dvd+rw-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dvd+rw-tools
Version:        7.1
Release:        63.2
Summary:        Collection of Tools for Mastering Blu-ray and DVD+-RW/+-R Media
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/CD/Record
URL:            http://fy.chalmers.se/~appro/linux/DVD+RW/
# http://fy.chalmers.se/~appro/linux/DVD+RW/tools/dvd+rw-tools-7.1.tar.gz
Source0:        %{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE utf8ize.patch sbrabec@suse.cz -- Convert some strings to UTF-8
Patch0:         utf8ize.patch
# PATCH-FIX-OPENSUSE growisofs-dvd-dl-undersized.patch bnc#164032 joeshaw@suse.de -- Allow users to burn images that would fit on a single-layer DVD to a dual-layer disc
Patch1:         growisofs-dvd-dl-undersized.patch
# NOTE: commented out. PATCH-FIX-OPENSUSE growisofs-genisoimage.patch nadvornik@suse.cz -- Make the package call genisoimage directly, not via compatibility symlink
Patch2:         growisofs-genisoimage.patch
# PATCH-FIX-OPENSUSE dvd+rw-tools-gcc43.patch ro@suse.de -- Fix build with gcc-4.3
Patch3:         dvd+rw-tools-gcc43.patch
# PATCH-FIX-OPENSUSE dvd+rw-tools-buffer.patch bnc#354838 nadvornik@suse.cz -- Fix buffer size
Patch4:         dvd+rw-tools-buffer.patch
# PATCH-FIX-UPSTREAM fix-build-with-recent-glibc.patch
Patch5:         fix-build-with-recent-glibc.patch
BuildRequires:  gcc-c++
BuildRequires:  m4
# According to Linux from scratch dvd+rw-tools needs this to function correctly with wodim
Requires:       %{_bindir}/mkisofs
Requires:       libisoburn1

%description
The dvd+rw-tools collection of tools makes it possible to burn images to
Blu-ray and DVD+-RW/+-R media.

%prep
%setup -q
%patch -P 0
%patch -P 1
%if 0
%patch -P 2
%endif
%patch -P 3
%patch -P 4
%patch -P 5 -p1

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="%{optflags} -fno-strict-aliasing"

make %{?_smp_mflags} CC="gcc" CXX="g++"
make rpl8 btcflash %{?_smp_mflags} CC="gcc" CXX="g++"

%install
make prefix=%{buildroot}%{_prefix} manprefix=%{buildroot}%{_mandir} install

# Rename btcflash binary in order to avoid conflict with btcflash from cdrtools
mv %{buildroot}%{_bindir}/btcflash %{buildroot}%{_bindir}/dvd+rw-tools-btcflash

%files
%license LICENSE
%doc index.html
%{_bindir}/dvd+rw-booktype
%{_bindir}/dvd+rw-format
%{_bindir}/dvd+rw-mediainfo
%{_bindir}/dvd+rw-tools-btcflash
%{_bindir}/dvd-ram-control
%{_bindir}/growisofs
%{_bindir}/rpl8
%{_mandir}/man1/growisofs.1%{?ext_man}

%changelog
* Thu Feb 29 2024 Takashi Iwai <tiwai@suse.com>
- Avoid comment out of patch application that leads to failure ot
  "osc service runall"
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Apr  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add fix-build-with-recent-glibc.patch.
- Refresh dvd+rw-tools-buffer.patch
- Refresh growisofs-dvd-dl-undersized.patch
- Run spec-cleaner
* Thu Feb  9 2017 dimstar@opensuse.org
- Explicitly BuildRequire m4.
* Fri May 10 2013 davejplater@gmail.com
- Change requirement from genisoimage to /usr/bin/mkisofs to allow
  the use of either wodim or cdrtools and commented out patch
  growisofs-genisoimage.patch as this prevents the use of cdrtools
  without user intervention.
* Wed Aug  8 2012 cfarrell@suse.com
- Update license in spec file to use SPDX format
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc, %%__cxx macros
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Sun Apr 10 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Added description for the patches based on openSUSE Patches Guidelines.
  * Added genisoimage in Requires:.
  * Updates in Summary: and %%description.
  * Compile the package with -fno-strict-aliasing.
  * Rename btcflash binary to "dvd+rw-tools-btcflash" in order to avoid
    conflict with btcflash from cdrtools.
  * Small updates in %%files section.
  * Remove the entries from %%changelog.
- Removed rpm_opt_flags.diff patch (not required since the flags can be set in
  the spec file).
* Tue Aug 19 2008 lnussel@suse.de
- remove resmgr from BuildRequires
* Mon Mar 10 2008 nadvornik@suse.cz
- update to 7.1
  * lock corresponding /dev/srN
  * add -F/-free-space option displaying next session offset and
    media capacity, which facilitates free space calculation
  * allow session to cross 4GB boundary even on single-layer media
  * return non-zero exit status more aggressively
* Mon Jan 21 2008 nadvornik@suse.cz
- fixed buffer size [#354838]
* Mon Nov 12 2007 ro@suse.de
- fix build with gcc-4.3
* Tue Jul 17 2007 nadvornik@suse.cz
- call genisoimage directly, not via compatibility symlink
* Wed Nov 15 2006 adrian@suse.de
- update to version 7.0
  * Blu-ray Disc support
  * Linux: overcome 16MB O_DIRECT limitaton for NFS client
- remove obsolete patches
* Thu Apr 27 2006 joeshaw@suse.de
- Add patch to allow users to burn images that would fit on a
  single-layer DVD to a dual-layer disc.  (bnc #164032)
* Wed Apr 12 2006 adrian@suse.de
- fix dvd burning from NFS located files (by okir, #149905)
* Tue Apr  4 2006 rw@suse.de
- don't set thread stacksize below PTHREAD_STACK_MIN (#160312)
* Sat Feb 18 2006 ak@suse.de
- expand memlock limit for 64bit systems (#152052)
* Mon Jan 30 2006 adrian@suse.de
- update to version 6.1 (#146534)
- sentinel, resmgr and subfs patch are obsolete
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct  5 2005 dmueller@suse.de
- add norootforbuild
* Wed Jun 29 2005 sbrabec@suse.cz
- Strings converted to UTF-8.
* Mon Apr 11 2005 meissner@suse.de
- and actually apply the last patch.
* Fri Apr  8 2005 meissner@suse.de
- explicitly use (char*)0 as execl terminator.
* Wed Jan 26 2005 meissner@suse.de
- Use RPM_OPT_FLAGS. Fixed gcc4 compile problem.
* Mon Jan 10 2005 adrian@suse.de
- fix resmgr support (#49388)
* Tue Sep 21 2004 ro@suse.de
- update to 5.21 as suggested for use with kernel >= 2.6.8
* Wed Aug 18 2004 ro@suse.de
- update to 5.20... to support DVD+R DL
* Tue Jul 27 2004 adrian@suse.de
- fix subfs.diff patch
* Mon Jul 26 2004 adrian@suse.de
- fix usage as user (non-root) #42523
  * add resmgr support
  * do not try to unmount subfs mounts
* Sat Mar 13 2004 aj@suse.de
- update to 5.17.4.8.6. [#35750]
* Thu Sep  4 2003 wengel@suse.de
- update -> 5.12.4.7.4
* Thu Jul 31 2003 wengel@suse.de
- fixed filelist
* Thu Jul 31 2003 wengel@suse.de
- update to new version -> 5.10.4.5.4
- minor specfile changes
* Wed May 28 2003 coolo@suse.de
- use BuildRoot
* Fri Jan 17 2003 wengel@suse.de
- initial package
